@@ -2,7 +2,6 @@
 /* gnome-vfs-error.c - Error handling for the GNOME Virtual File System.
 
    Copyright (C) 1999 Free Software Foundation
-   Copyright (C) 2007 Thadeu Lima de Souza Cascardo
 
    The Gnome Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License as
@@ -20,28 +19,20 @@
    Boston, MA 02111-1307, USA.
 
    Author: Ettore Perazzoli <ettore@gnu.org>
-
-   Modified on 2007-01-29 by Thadeu Lima de Souza Cascardo to handle
-   ENOTSUP.
-
 */
 
 #include <config.h>
 #include "gnome-vfs-result.h"
 
+#include "gnome-vfs-i18n.h"
 #include <glib/gtypes.h>
-#include <glib/gi18n-lib.h>
 #include <errno.h>
-#ifndef G_OS_WIN32
 #include <netdb.h>
-#endif
 
-#ifndef G_OS_WIN32
 /* AIX #defines h_errno */
 #ifndef h_errno
 extern int h_errno;
 #endif
-#endif
 
 static char *status_strings[] = {
 	/* GNOME_VFS_OK */				N_("No error"),
@@ -92,20 +83,20 @@ static char *status_strings[] = {
 	/* GNOME_VFS_ERROR_LAUNCH */			N_("Error launching command"),
 	/* GNOME_VFS_ERROR_TIMEOUT */			N_("Timeout reached"),
 	/* GNOME_VFS_ERROR_NAMESERVER */                N_("Nameserver error"),
+	/* GNOME_VFS_ERROR_TIMEOUT */			N_("Timeout reached"),
  	/* GNOME_VFS_ERROR_LOCKED */			N_("The resource is locked"),
-	/* GNOME_VFS_ERROR_DEPRECATED_FUNCTION */       N_("Function call deprecated"),
-	/* GNOME_VFS_ERROR_INVALID_FILENAME */		N_("Invalid filename"),
-	/* GNOME_VFS_ERROR_NOT_A_SYMBOLIC_LINK */	N_("Not a symbolic link")
+	/* GNOME_VFS_ERROR_DEPRECATED_FUNCTION */       N_("Function call deprecated")
 };
 
+
 /**
- * gnome_vfs_result_from_errno_code:
- * @errno_code: integer of the same type as the system "errno".
+ * gnome_vfs_result_from_errno_code
+ * @errno_code: integer of the same type as the system "errno"
  *
- * Converts a system errno value to a #GnomeVFSResult.
+ * Converts a system errno value to a GnomeVFSResult.
  *
- * Return value: a #GnomeVFSResult equivalent to @errno_code.
- */
+ * Return value: a GnomeVFSResult equivalent to @errno_code
+ **/
 GnomeVFSResult
 gnome_vfs_result_from_errno_code (int errno_code)
 {
@@ -115,9 +106,7 @@ gnome_vfs_result_from_errno_code (int errno_code)
 	case EACCES:	   return GNOME_VFS_ERROR_ACCESS_DENIED;
 	case EBUSY:	   return GNOME_VFS_ERROR_DIRECTORY_BUSY;
 	case EBADF:	   return GNOME_VFS_ERROR_BAD_FILE;
-#ifdef ECONNREFUSED
 	case ECONNREFUSED: return GNOME_VFS_ERROR_SERVICE_NOT_AVAILABLE;
-#endif
 	case EEXIST:	   return GNOME_VFS_ERROR_FILE_EXISTS;
 	case EFAULT:	   return GNOME_VFS_ERROR_INTERNAL;
 	case EFBIG:	   return GNOME_VFS_ERROR_TOO_BIG;
@@ -125,14 +114,10 @@ gnome_vfs_result_from_errno_code (int errno_code)
 	case EINVAL:	   return GNOME_VFS_ERROR_BAD_PARAMETERS;
 	case EIO:	   return GNOME_VFS_ERROR_IO;
 	case EISDIR:	   return GNOME_VFS_ERROR_IS_DIRECTORY;
-#ifdef ELOOP
 	case ELOOP:	   return GNOME_VFS_ERROR_LOOP;
-#endif
 	case EMFILE:	   return GNOME_VFS_ERROR_TOO_MANY_OPEN_FILES;
 	case EMLINK:	   return GNOME_VFS_ERROR_TOO_MANY_LINKS;
-#ifdef ENETUNREACH
 	case ENETUNREACH:  return GNOME_VFS_ERROR_SERVICE_NOT_AVAILABLE;
-#endif
 	case ENFILE:	   return GNOME_VFS_ERROR_TOO_MANY_OPEN_FILES;
 #if ENOTEMPTY != EEXIST
 	case ENOTEMPTY:    return GNOME_VFS_ERROR_DIRECTORY_NOT_EMPTY;
@@ -143,14 +128,8 @@ gnome_vfs_result_from_errno_code (int errno_code)
 	case ENOTDIR:	   return GNOME_VFS_ERROR_NOT_A_DIRECTORY;
 	case EPERM:	   return GNOME_VFS_ERROR_NOT_PERMITTED;
 	case EROFS:	   return GNOME_VFS_ERROR_READ_ONLY_FILE_SYSTEM;
-#ifdef ETIMEDOUT
 	case ETIMEDOUT:    return GNOME_VFS_ERROR_TIMEOUT;
-#endif
 	case EXDEV:	   return GNOME_VFS_ERROR_NOT_SAME_FILE_SYSTEM;
-	case ENAMETOOLONG: return GNOME_VFS_ERROR_NAME_TOO_LONG;
-#ifdef ENOTSUP
-	case ENOTSUP:    return GNOME_VFS_ERROR_NOT_SUPPORTED;
-#endif
 	
 		/* FIXME bugzilla.eazel.com 1191: To be completed.  */
 	default:	return GNOME_VFS_ERROR_GENERIC;
@@ -160,25 +139,25 @@ gnome_vfs_result_from_errno_code (int errno_code)
 /**
  * gnome_vfs_result_from_errno:
  * 
- * Converts the system errno to a #GnomeVFSResult.
+ * Converts the system errno to a GnomeVFSResult.
  *
- * Return value: a #GnomeVFSResult equivalent to the current system errno.
- */
+ * Return value: a GnomeVFSResult equivalent to the current system errno
+ **/
 GnomeVFSResult
 gnome_vfs_result_from_errno (void)
 {
        return gnome_vfs_result_from_errno_code(errno);
 }
  
-#ifndef G_OS_WIN32
+
 /**
  * gnome_vfs_result_from_h_errno:
  * 
- * Converts the system "h_errno" to a #GnomeVFSResult (h_errno represents errors
+ * Converts the system "h_errno" to a GnomeVFSResult (h_errno represents errors
  * accessing and finding internet hosts)
  *
- * Return value: a #GnomeVFSResult equivalent to the current system "h_errno".
- */
+ * Return value: a GnomeVFSResult equivalent to the current system "h_errno"
+ **/
 GnomeVFSResult
 gnome_vfs_result_from_h_errno (void)
 {
@@ -187,17 +166,17 @@ gnome_vfs_result_from_h_errno (void)
 
 /**
  * gnome_vfs_result_from_h_errno_val:
- * @h_errno_code: an integer representing the same error code
+ * @h_errno_code: A integer containing representing the same error codes
  * as the system h_errno.
  * 
- * Converts the error code @h_errno_code into a #GnomeVFSResult.
+ * Converts the error code of @h_errno into a #GnomeVFSResult.
  * 
- * Return Value: The #GnomeVFSResult equivalent to the @h_errno_code.
- */
+ * Return Value: The #GnomeVFSResult equivalent to the h_errno error code.
+ **/
 GnomeVFSResult
 gnome_vfs_result_from_h_errno_val (int h_errno_code)
 {
-	switch (h_errno_code) {
+	switch (h_errno) {
 	case HOST_NOT_FOUND:	return GNOME_VFS_ERROR_HOST_NOT_FOUND;
 	case NO_ADDRESS:	return GNOME_VFS_ERROR_HOST_HAS_NO_ADDRESS;
 	case TRY_AGAIN:		return GNOME_VFS_ERROR_NAMESERVER;
@@ -206,17 +185,16 @@ gnome_vfs_result_from_h_errno_val (int h_errno_code)
 		return GNOME_VFS_ERROR_GENERIC;
 	}
 }
-#endif
 
 /**
  * gnome_vfs_result_to_string:
- * @result: a #GnomeVFSResult to convert to a string.
+ * @result: the result to convert to a string
  *
- * Returns a string representing @result, useful for debugging
+ * Returns a string representation of @result, useful for debugging
  * purposes, but probably not appropriate for passing to the user.
  *
- * Return value: a string representing @result.
- */
+ * Return value: a string representing @result
+ **/
 const char *
 gnome_vfs_result_to_string (GnomeVFSResult result)
 {
